Module: Appsignal::Integrations::RakeIntegration
- Defined in:
- lib/appsignal/integrations/rake.rb
Constant Summary collapse
- IGNORED_ERRORS =
[ # Normal exits from the application we do not need to report SystemExit, SignalException ].freeze
[ # Normal exits from the application we do not need to report SystemExit, SignalException ].freeze